---
version: draft
---

write ingress:

ingress/images/


ls *.png | f/ingress/images/shape=berg

--->


PG? ES?


--->


read fuse query:

$ ls f/query/images/
shape
obj-reco


$ f/query/images/shape
berg
tal


f/query/images/shape=berg/.elasticsearch-query
f/query/images/shape=berg/.sql-query
f/query/images/shape=berg,obj-reco=cat/
  - sha1-hash-hier.png -> original/path/ffoo.png
  - sha1-hash-hier.png
nas/query/images/shape=berg,obj-reco=cat
enterprise/query/images/shape=berg,obj-reco=cat

diff/query/images/shape=berg,obj-reco=cat,id=234523424234

STDERR: wirklich diff von allen files (30 TB)?


- anything locally / sshfs = read/write
- nginx = read
- webdav = write
